@@ -9,6 +9,7 @@ from ibis.expr.types import TableExpr
 from lark import Token, Tree, v_args
 
 from sql_to_ibis.exceptions.sql_exception import (
+    ColumnNotFoundError,
     InvalidQueryException,
     TableExprDoesNotExist,
 )
@@ -16,6 +17,7 @@ from sql_to_ibis.parsing.transformers import InternalTransformer, TransformerBas
 from sql_to_ibis.query_info import QueryInfo
 from sql_to_ibis.sql_objects import (
     Aggregate,
+    AliasRegistry,
     AmbiguousColumn,
     Column,
     CrossJoin,
@@ -89,6 +91,7 @@ class SQLTransformer(TransformerBaseClass):
             column_to_table_name,
             _temp_dataframes_dict={},
         )
+        self._alias_registry = AliasRegistry()
 
     def add_column_to_column_to_dataframe_name_map(self, column, table):
         """
@@ -117,17 +120,20 @@ class SQLTransformer(TransformerBaseClass):
         :return:
         """
         table_name = table_name.lower()
-        if table_name not in self.table_name_map:
+        if table_name not in self._table_name_map:
             raise TableExprDoesNotExist(table_name)
-        true_name = self.table_name_map[table_name]
+        true_name = self._table_name_map[table_name]
         if isinstance(alias, Tree) and alias.data == "alias_string":
             alias_token: Token = alias.children[0]
             alias = alias_token.value
-        return Table(
-            value=self.table_map[true_name].get_table_expr(),
+        table = Table(
+            value=self._table_map[true_name].get_table_expr(),
             name=true_name,
             alias=alias,
         )
+        if alias:
+            self._alias_registry.add_to_registry(alias, table)
+        return table
 
     def order_by_expression(self, rank_tree):
         """
@@ -184,7 +190,7 @@ class SQLTransformer(TransformerBaseClass):
         subquery = Subquery(
             name=alias_name, query_info=query_info, value=subquery_value
         )
-        self.table_map[alias_name] = subquery
+        self._table_map[alias_name] = subquery
         self._column_name_map[alias_name] = {}
         for column in subquery.column_names:
             self.add_column_to_column_to_dataframe_name_map(column.lower(), alias_name)
@@ -217,7 +223,7 @@ class SQLTransformer(TransformerBaseClass):
         left_columns = self._column_name_map[left_table.name]
         right_columns = self._column_name_map[right_table.name]
         if column not in left_columns and column not in right_columns:
-            raise Exception("Column not found")
+            raise ColumnNotFoundError(column, [left_table.name, right_table.name])
 
         left_table_name = left_table.name.lower()
         right_table_name = right_table.name.lower()
@@ -385,9 +391,13 @@ class SQLTransformer(TransformerBaseClass):
             and select_expression.data not in ("having_expr", "where_expr")
             or not isinstance(select_expression, Tree)
         )
-
         internal_transformer = InternalTransformer(
-            tables, self.table_map, self._column_name_map, self._column_to_table_name,
+            tables,
+            self._table_map,
+            self._column_name_map,
+            self._column_to_table_name,
+            self._table_name_map,
+            self._alias_registry,
         )
 
         select_expressions = internal_transformer.transform(
