@@ -10,6 +10,7 @@ import pytest
 
 from sql_to_ibis import query, register_temp_table, remove_temp_table
 from sql_to_ibis.exceptions.sql_exception import (
+    ColumnNotFoundError,
     InvalidQueryException,
     TableExprDoesNotExist,
 )
@@ -1434,6 +1435,27 @@ def test_column_values_in_subquery():
     assert_ibis_equal_show_diff(ibis_table, my_table)
 
 
+@assert_state_not_change
+def test_select_column_with_table():
+    my_table = query("select forest_fires.wind from forest_fires")
+    ibis_table = FOREST_FIRES[FOREST_FIRES.wind]
+    assert_ibis_equal_show_diff(my_table, ibis_table)
+
+
+@assert_state_not_change
+def test_select_column_with_alias_prefix():
+    my_table = query("select table1.wind from forest_fires table1")
+    ibis_table = FOREST_FIRES[FOREST_FIRES.wind]
+    assert_ibis_equal_show_diff(my_table, ibis_table)
+
+
+@assert_state_not_change
+def test_select_ambiguous_column_in_database_context():
+    my_table = query("select attribute from digimon_mon_list")
+    ibis_table = DIGIMON_MON_LIST[DIGIMON_MON_LIST.Attribute.name("attribute")]
+    assert_ibis_equal_show_diff(my_table, ibis_table)
+
+
 # TODO Not implemented in ibis
 # @assert_state_not_change
 # def test_group_by_having():
@@ -1448,6 +1470,21 @@ def test_column_values_in_subquery():
 #     assert_ibis_equal_show_diff(ibis_table, my_table)
 
 
+@pytest.mark.parametrize(
+    "sql",
+    [
+        "select not_here from forest_fires",
+        "select * from digimon_mon_list join "
+        "digimon_move_list on "
+        "digimon_mon_list.not_here = digimon_move_list.attribute",
+        "select forest_fires.not_here from forest_fires",
+    ],
+)
+def test_raise_error_for_choosing_column_not_in_table(sql: str):
+    with pytest.raises(ColumnNotFoundError):
+        query(sql)
+
+
 @pytest.mark.parametrize(
     "sql",
     [
@@ -1476,5 +1513,5 @@ if __name__ == "__main__":
     #     DIGIMON_MON_LIST, DIGIMON_MOVE_LIST, "DIGIMON_MON_LIST", "DIGIMON_MOVE_LIST"
     # )
     # test_joins(digimon_move_mon_join_columns, "inner", "inner")
-    test_select_star()
+    test_select_column_with_alias_prefix()
     remove_env_tables()
